DiscussionRootNode class final
- Inheritance
-
- Object
- DiscussionNode
- DiscussionRootNode
Constructors
-
DiscussionRootNode({required int messageCount, required String subject, required bool withResponse, required String messageIdForParticipants, required String? public, required int? publicCount, required String? initiator, required bool read, required String dateLabel, required DateTime parsedDateLabel, required bool closeable, required bool closed, required bool canEdit, required String id, required int index, required List<
MessageRecipient> recipients, required bool isNotARecipient, required int depth, required List<DiscussionNode> children}) -
const
-
DiscussionRootNode.decode(int index, List<
DiscussionNode> children) -
factory
Properties
- cacheType → CacheType?
-
no setteroverride
- canEdit → bool
-
final
-
children
→ List<
DiscussionNode> -
finalinherited
- closeable → bool
-
final
- closed → bool
-
final
- dateLabel → String
-
final
- depth → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- index → int
-
finalinherited
- initiator → String?
-
Null means the initiator is the current user.
final
- isNotARecipient → bool
-
finalinherited
- messageCount → int
-
final
- messageIdForParticipants → String
-
final
- overrideSerialId → SerialObjectId?
-
no setterinherited
- parsedDateLabel → DateTime
-
final
- public → String?
-
final
- publicCount → int?
-
final
- read → bool
-
final
-
recipients
→ List<
MessageRecipient> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitive → bool
-
no setterinherited
- subject → String
-
final
-
toStore
→ List<
VisualNavigator> -
no setterinherited
- visualId → String
-
no setterinherited
- visualIdBytes → Uint8List
-
no setterinherited
- visualIdUrl → String
-
no setterinherited
- withResponse → bool
-
final
Methods
-
collectVisualIdData(
) → Iterable< Uint8List?> -
override
-
flatten(
) → List< DiscussionNode> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited