Holiday class final

Mixed-in types

Constructors

Holiday({required String id, required String name, required DateTime startDate, required DateTime endDate})
const
Holiday.decode(Map<String, dynamic> nav)
factory

Properties

cacheType CacheType?
no setteroverride
endDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
overrideSerialId SerialObjectId?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool
no setterinherited
startDate DateTime
final
toStore List<VisualNavigator>
no setterinherited
visualId String
no setterinherited
visualIdBytes Uint8List
no setterinherited
visualIdUrl String
no setterinherited

Methods

collectVisualIdData() Iterable<Uint8List?>
override
contains(DateTime day) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited