Homework class final

Mixed-in types

Constructors

Homework({required String id, required int? type, required Subject subject, required String description, required int? order, required Date deadlineDate, required Date givenDate, required int backgroundColor, required int textColor, required int difficultyLevel, required double duration, required List<Attachment> attachments, required bool isDone, required bool withRender, required HomeworkRenderType assignmentToRenderType, required bool canHandAssignment, required HandedAssignment? handedAssignment, required DateTime? assignmentHandedTime, required String? assignmentCorrectionComment, required bool withFormatting, required String? publicName, required String? notebookEntryId, required String? lessonId, required List<Theme> themes})
const
Homework.decode(Map<String, dynamic> nav)
factory

Properties

assignmentCorrectionComment String?
final
assignmentHandedTime DateTime?
final
assignmentToRenderType HomeworkRenderType
final
attachments List<Attachment>
final
backgroundColor int
final
cacheType CacheType?
no setteroverride
canHandAssignment bool
final
deadlineDate Date
final
description String
final
difficultyLevel int
final
duration double
final
givenDate Date
final
handedAssignment HandedAssignment?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDone bool
final
lessonId String?
final
notebookEntryId String?
final
order int?
final
overrideSerialId SerialObjectId?
no setterinherited
publicName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool
no setterinherited
subject Subject
final
textColor int
final
themes List<Theme>
final
toStore List<VisualNavigator>
no setteroverride
type int?
final
visualId String
no setterinherited
visualIdBytes Uint8List
no setterinherited
visualIdUrl String
no setterinherited
withFormatting bool
final
withRender bool
final

Methods

collectVisualIdData() Iterable<Uint8List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited