NewsQuestion class final

Mixed-in types

Constructors

NewsQuestion({required String label, required String id, required int place, required int rank, required NewsQuestionAnswerType responseType, required String title, required String htmlText, required int responseSize, required bool withMaximum, required int maximumResponseCount, required List<Attachment> attachments, required List<NewsQuestionPick> picks, required NewsQuestionAnswer answer})
const
NewsQuestion.decode(Map<String, dynamic> nav)
factory

Properties

answer NewsQuestionAnswer
final
attachments List<Attachment>
final
cacheType CacheType?
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
htmlText String
final
id String
final
label String
final
maximumResponseCount int
final
overrideSerialId SerialObjectId?
no setterinherited
picks List<NewsQuestionPick>
final
place int
final
rank int
final
responseSize int
final
responseType NewsQuestionAnswerType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool
no setterinherited
title String
final
toStore List<VisualNavigator>
no setteroverride
visualId String
no setterinherited
visualIdBytes Uint8List
no setterinherited
visualIdUrl String
no setterinherited
withMaximum bool
final

Methods

collectVisualIdData() Iterable<Uint8List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited