NotebookPage class final

Mixed-in types

Constructors

NotebookPage({required List<NotebookEntry> entries, required PedagogicalResourceSet? resourceSet, required Map<String, dynamic>? numericResourceSet, required NotebookHomeworkSet? homeworkSet})
const
NotebookPage.decode(Map<String, dynamic> nav)
factory

Properties

cacheType CacheType?
no setteroverride
entries List<NotebookEntry>
final
hashCode int
The hash code for this object.
no setterinherited
homeworkSet → NotebookHomeworkSet?
final
numericResourceSet Map<String, dynamic>?
final
overrideSerialId SerialObjectId?
no setterinherited
resourceSet PedagogicalResourceSet?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool
no setterinherited
toStore List<VisualNavigator>
no setteroverride
visualId VisualId
no setterinherited
visualIdBytes Uint8List
no setterinherited
visualIdUrl VisualId
no setterinherited

Methods

collectVisualIdData() Iterable<Uint8List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() VisualId
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited