OrientationSectionType enum

Inheritance
Implemented types
Available extensions

Values

familyWish → const OrientationSectionType
const OrientationSectionType(0)
otherBoardRecommendation → const OrientationSectionType
const OrientationSectionType(1)
definitiveWish → const OrientationSectionType
const OrientationSectionType(2, yesNoMode: true)
otherBoardProposal → const OrientationSectionType
const OrientationSectionType(3)
finalDecision → const OrientationSectionType
const OrientationSectionType(4)
effectiveOrientation → const OrientationSectionType
const OrientationSectionType(5)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
yesNoMode bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OrientationSectionType>
A constant List of the values in this enum, in order of their declaration.