StudentClass class final

Mixed-in types

Constructors

StudentClass({required String id, required String name})
const
StudentClass.decode(Map<String, dynamic> nav)
factory

Properties

cacheType CacheType?
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
overrideSerialId SerialObjectId?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool
no setterinherited
toStore List<VisualNavigator>
no setterinherited
visualId String
no setterinherited
visualIdBytes Uint8List
no setterinherited
visualIdUrl String
no setterinherited

Methods

collectVisualIdData() Iterable<Uint8List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRaw() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited