CacheType class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- CLASS_CONTENT → const CacheType
- CLASS_GROUP → const CacheType
- CLASSROOM → const CacheType
- CLAZZ → const CacheType
- DISCUSSION_MESSAGE → const CacheType
- DISCUSSION_NODE → const CacheType
- EXAM → const CacheType
- EXAM_PREVIEW → const CacheType
- FILE_ATTACHMENT → const CacheType
- FOOD → const CacheType
- FOOD_ALLERGEN → const CacheType
- FOOD_LABEL → const CacheType
- HANDED_ASSIGNMENT → const CacheType
- HOLIDAY → const CacheType
- HOMEWORK → const CacheType
- LINK_ATTACHMENT → const CacheType
- MCQ → const CacheType
- MCQ_EXECUTION → const CacheType
- MEAL → const CacheType
- NEWS → const CacheType
- NEWS_CATEGORY → const CacheType
- NEWS_QUESTION → const CacheType
- NEWS_QUESTION_ANSWER → const CacheType
- NEWS_QUESTION_PICK → const CacheType
- NOTEBOOK_CONTENT → const CacheType
- NOTEBOOK_CONTENT_CATEGORY → const CacheType
- NOTEBOOK_ENTRY → const CacheType
- NOTEBOOK_ENTRY_GROUP → const CacheType
- NOTEBOOK_ENTRY_PREVIEW → const CacheType
- NOTEBOOK_RESOURCE → const CacheType
- NOTEBOOK_RESOURCE_ENTRY → const CacheType
- PEDAGOGICAL_FORUM → const CacheType
- PERIOD → const CacheType
- PERSON → const CacheType
- ROOM → const CacheType
- SCHOOL_LIFE_EVENT → const CacheType
- SCHOOL_LIFE_EVENT_REASON → const CacheType
- SCHOOL_LIFE_EVENT_SECTION → const CacheType
- SERVICE → const CacheType
- STUDENT_CLASS → const CacheType
- SUBJECT → const CacheType
- SUBMITTED_FILE_ATTACHMENT → const CacheType
- THEME → const CacheType
- UNIQUE → const CacheType
- SPECIAL CACHE TYPE
- USER_RESOURCE → const CacheType
-
values
→ const List<
CacheType>