DiscussionAccessor class final
- Inheritance
-
- Object
- Accessor<
Discussion> - DiscussionAccessor
Constructors
- DiscussionAccessor({required DiscussionRootNode node, bool markAsRead = true})
-
const
Properties
- exclusiveFriendly → bool
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- markAsRead → bool
-
final
- node → DiscussionRootNode
-
final
- page → int?
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
access(
RemoteSession session, Completer< void> ? cancellationSignal) → FutureOr<Map< String, dynamic> > -
override
-
fetch(
RemoteSession session, Completer< void> ? cancellationSignal) → Future<Discussion> -
inherited
-
interpret(
RemoteSession session) → FutureOr< Discussion> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
store(
Discussion result) → List< VisualNavigator> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited