DiscussionPage class final
- Mixed-in types
Constructors
-
DiscussionPage({required List<
DiscussionLabel> labels, required List<DiscussionRootNode> discussions}) -
const
- DiscussionPage.decode()
-
factory
Properties
- cacheType → CacheType?
-
no setteroverride
-
discussions
→ List<
DiscussionRootNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ List<
DiscussionLabel> -
final
- overrideSerialId → SerialObjectId?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitive → bool
-
no setterinherited
-
toStore
→ List<
VisualNavigator> -
no setteroverride
- visualId → VisualId
-
no setterinherited
- visualIdBytes → Uint8List
-
no setterinherited
- visualIdUrl → VisualId
-
no setterinherited
Methods
-
collectVisualIdData(
) → Iterable< Uint8List?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → VisualId -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited