SerialObjectId enum
Values
- instanceParameters → const SerialObjectId
-
const SerialObjectId('instance') - userParameters → const SerialObjectId
-
const SerialObjectId('user') - authenticationData → const SerialObjectId
-
const SerialObjectId('auth') - challenge → const SerialObjectId
-
const SerialObjectId('challenge') - offPeriod → const SerialObjectId
-
const SerialObjectId('off_period')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- writtenId → VisualId
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → VisualId -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SerialObjectId> - A constant List of the values in this enum, in order of their declaration.