UserAuthorizations class final
Constructors
-
UserAuthorizations({required bool canReadDiscussions, required bool canDiscuss, required bool canDiscussWithStaff, required bool canDiscussWithParents, required bool canDiscussWithStudents, required bool canDiscussWithTeachers, required bool hasAdvancedDiscussionEditor, required double? maxAssignmentFileUploadSize, required List<
int> tabLocations}) -
const
- UserAuthorizations.decode()
-
factory
Properties
- canDiscuss → bool
-
final
- canDiscussWithParents → bool
-
final
- canDiscussWithStaff → bool
-
final
- canDiscussWithStudents → bool
-
final
- canDiscussWithTeachers → bool
-
final
- canReadDiscussions → bool
-
final
- hasAdvancedDiscussionEditor → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAssignmentFileUploadSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tabLocations
→ List<
int> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited